#include <stdio.h>
#include <stdlib.h>
#include <SDL2/SDL.h>
#include <SDL2/SDL_image.h>
#include "map.h"
#include "personnage.h"
#include "prof.h"
#include "DS.h"
#include "GAME.h"
#include "move.h"
#include "button.h"




int main(int argc, char* args[])
{
	//Init SDL soft with timer
    if ( SDL_Init(SDL_INIT_VIDEO|SDL_INIT_TIMER) != 0)
    {
        printf("Cannot init SDL GAME, Error : %s\n", SDL_GetError());
        return 1;
    }

    // create a new window
    SDL_Window * window = SDL_CreateWindow("INSAGAME",SDL_WINDOWPOS_CENTERED,SDL_WINDOWPOS_CENTERED,WINDOW_WIDTH+2,WINDOW_HEIGHT+2,0);
    if (!window)
    {
        printf("Cannot create new window: %s\n", SDL_GetError());
        SDL_Quit();
        return 1;
    }

    // create a new renderer for graphic sofware
    Uint32 render_flags = SDL_RENDERER_ACCELERATED;
    SDL_Renderer* renderer = SDL_CreateRenderer(window, -1, render_flags);
    if (!renderer)
    {
        printf("Cannot create renderer: %s\n", SDL_GetError());
        SDL_DestroyWindow(window);
        SDL_Quit();
        return 1;
    }

    //show the beginning
    int show_begin_page = show_image_in_time(renderer,window,"ressource/begin.png",2000);

    if (show_begin_page) {
        return 1;
    }

    int show_instruction_page = show_image_in_time(renderer,window,"ressource/gameinstruction.png",2000);

    if (show_instruction_page) {
        return 1;
    }


	//Create the Map and query its texture
	MAP map_game;
    SDL_Texture * texture_map = query_map(&map_game, renderer, window);

	//create a Personnage "hero" and query its texture
	Personnage hero;
    SDL_Rect hero_rect;
    SDL_Texture *texture_hero = query_hero(&hero,&hero_rect,renderer,window);

	//create a Prof "teacher" and query its texture
	Prof teacher;
    SDL_Rect teacher_rect;
    SDL_Texture* texture_teacher = query_teacher(&teacher, &teacher_rect, renderer, window);

	//Create a DS "exam" and its texture
	DS exam;
    SDL_Rect exam_rect;
    SDL_Texture * texture_exam = query_exam(&exam, &exam_rect, renderer, window);

    if(!texture_map || !texture_hero || !texture_teacher || !texture_exam){
        return 1;
    }

    //result variable
    int result = 0;

    // set to 1 when window close button is pressed
    int close_request = 0;

    //begin game variable
    int first=1;

    //direction aleatoire du prof
    int direction_teacher;

    // game loop
    while (!close_request)
    {
        // process events
        SDL_Event event_hero;

        //test key up-down-left-right
        test_event_hero(&hero,&event_hero,&close_request);

        //move the hero
        move_hero(&hero,&hero_rect,&teacher,&exam,&map_game,&close_request,&result);


        //move the teacher
        if(first==1){
            fflush(stdin);
            direction_teacher = rand()%4;
            first=0;
        }
        else prof_move(&teacher, &direction_teacher, &teacher_rect, &map_game, &exam);

        // clear the window
        SDL_RenderClear(renderer);

        // draw the image to the window
        SDL_RenderCopy(renderer, texture_map, NULL, NULL);
        SDL_RenderCopy(renderer, texture_hero, NULL, &hero_rect);
        SDL_RenderCopy(renderer, texture_teacher, NULL, &teacher_rect);
        SDL_RenderCopy(renderer, texture_exam, NULL, &exam_rect);
        SDL_RenderPresent(renderer);

        // wait 17ms
		SDL_Delay(17);
    }

    //Destroy Everytexture
	SDL_DestroyTexture(texture_map);
	SDL_DestroyTexture(texture_hero);
	SDL_DestroyTexture(texture_teacher);
	SDL_DestroyTexture(texture_exam);

	//End Game, show result

    result_game(result,renderer,window);
	
    //Destroy Everything
    SDL_DestroyRenderer(renderer);
    SDL_DestroyWindow(window);
    SDL_Quit();

    return 0;
}
